WordMaze
[![PyPI version fury.io](https://img.shields.io/pypi/v/wordmaze?color=blue)](https://github.com/elint-tech/wordmaze)
[![PyPI pyversions](https://img.shields.io/pypi/pyversions/wordmaze)](https://github.com/elint-tech/wordmaze)
===

*Words and textboxes made amazing.*

# About

- TODO: write About section

# Usage

- TODO: write Usage section

# Installing

Install from [PyPI](https://pypi.org/project/wordmaze/):
```
pip install wordmaze
```

# Projects using WordMaze

* [elint-tech/pdfmap](https://github.com/elint-tech/pdfmap): easily extract textboxes from PDF files.
